@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/doric-themes
-;; Version: 0.3.0
+;; Version: 0.4.0
 ;; Package-Requires: ((emacs "29.1"))
 ;; Keywords: faces, theme, accessibility
 
@@ -173,8 +173,6 @@ With optional PROMPT string, use it.  Else use a generic prompt."
 ;;;###autoload
 (defun doric-themes-select (theme)
   "Load a Doric THEME using minibuffer completion.
-Disable other themes per `doric-themes-disable-other-themes'.
-
 Run `doric-themes-after-load-theme-hook' after loading the theme."
   (interactive (list (doric-themes-select-prompt)))
   (doric-themes-load-theme theme))
@@ -301,7 +299,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     avy-lead-face-0
     avy-lead-face-1
     avy-lead-face-2
-    calendar-today
     completions-highlight
     consult-highlight-mark
     consult-highlight-match
@@ -388,7 +385,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     company-tooltip-scrollbar-track
     consult-preview-line
     corfu-popupinfo
-    diary
     ediff-even-diff-A
     ediff-even-diff-Ancestor
     ediff-even-diff-B
@@ -676,6 +672,11 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     woman-addition
     ztreep-node-face))
 
+(defconst doric-themes-bold-accent-foreground-only-faces
+  '(diary
+    magit-diff-file-heading
+    org-imminent-deadline))
+
 (defconst doric-themes-main-foreground-only-faces
   '(border
     breadcrumb-imenu-crumbs-face
@@ -987,6 +988,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     elfeed-search-unread-title-face
     git-commit-comment-heading
     git-commit-summary
+    line-number-current-line
     log-edit-header
     magit-section-heading
     markdown-metadata-key-face
@@ -1099,6 +1101,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     gnus-group-news-low-empty
     gnus-server-offline
     help-argument-name
+    holiday
     line-number-minor-tick
     magit-branch-current
     magit-cherry-unmatched
@@ -1392,6 +1395,11 @@ default a generic text that mentions the BACKGROUND-MODE."
 
             `(aw-leading-char-face ((t :inherit bold-italic :height 1.5 :foreground ,fg-accent)))
 
+            `(calendar-today
+              ((default :background ,bg-accent :foreground ,fg-main)
+               (((supports :box t))
+                :box (:line-width (-1 . -1) :color ,fg-accent))))
+
             `(company-tooltip ((t :inherit fixed-pitch :background ,bg-shadow-subtle :foreground ,fg-shadow-subtle)))
 
             `(corfu-default ((t :inherit fixed-pitch :background ,bg-shadow-subtle :foreground ,fg-shadow-subtle)))
@@ -1415,6 +1423,7 @@ default a generic text that mentions the BACKGROUND-MODE."
             ,@(doric-themes-prepare-faces doric-themes-intense-shadow-foreground-only-faces :foreground 'fg-shadow-intense)
             ,@(doric-themes-prepare-faces doric-themes-subtle-shadow-foreground-only-faces :foreground 'fg-shadow-subtle)
             ,@(doric-themes-prepare-faces doric-themes-accent-foreground-only-faces :foreground 'fg-accent)
+            ,@(doric-themes-prepare-faces doric-themes-bold-accent-foreground-only-faces :inherit ''bold  :foreground 'fg-accent)
             ,@(doric-themes-prepare-faces doric-themes-main-foreground-only-faces :foreground 'fg-main)
 
             ,@(doric-themes-prepare-faces doric-themes-error-foreground-only-faces :inherit ''bold :foreground 'fg-red)
@@ -1506,8 +1515,6 @@ default a generic text that mentions the BACKGROUND-MODE."
                (((class color) (min-colors 88) (background dark))
                 :background "#000000" :foreground "#cab000")))
 
-            `(holiday ((t :inherit bold :background ,bg-shadow-subtle :foreground ,fg-main)))
-
             `(isearch ((t :background ,bg-shadow-intense :foreground ,fg-main)))
             `(isearch-fail ((t :inherit (underline bold))))
             `(isearch-group-1 ((t :background ,bg-accent :foreground ,fg-accent)))
@@ -1531,10 +1538,7 @@ default a generic text that mentions the BACKGROUND-MODE."
             `(lin-red-override-fg ((t :background ,bg-red :foreground ,fg-main)))
             `(lin-yellow-override-fg ((t :background ,bg-yellow :foreground ,fg-main)))
 
-            `(line-number-current-line ((t :inherit bold :background ,bg-accent :foreground ,fg-accent)))
-
             `(magit-diff-context-highlight ((t :background ,bg-shadow-subtle :foreground ,fg-shadow-subtle)))
-            `(magit-diff-file-heading ((t :inherit bold :foreground ,fg-accent)))
             `(magit-diff-file-heading-highlight ((t :inherit magit-diff-file-heading :background ,bg-shadow-subtle)))
             `(magit-diff-file-heading-selection ((t :inherit bold :background ,bg-accent)))
             `(magit-diff-hunk-heading ((t :background ,bg-shadow-subtle)))
@@ -1579,16 +1583,12 @@ default a generic text that mentions the BACKGROUND-MODE."
             '(org-checkbox ((t :inherit fixed-pitch)))
             `(org-code ((t :inherit (fixed-pitch italic) :foreground ,fg-shadow-subtle)))
             `(org-column-title ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
-            `(org-date-selected
-              ((default :background ,bg-accent :foreground ,fg-main)
-               (((supports :box t))
-                :box (:line-width (-1 . -1) :color ,fg-accent))))
+            '(org-date-selected ((t :inherit calendar-today)))
             `(org-document-info-keyword ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
             `(org-drawer ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
             `(org-ellipsis (( ))) ; inherits from the heading's color
             '(org-formula ((t :inherit fixed-pitch)))
             `(org-hide ((t :foreground ,bg-main)))
-            `(org-imminent-deadline ((t :inherit bold :foreground ,fg-accent)))
             `(org-indent ((t :inherit (fixed-pitch org-hide))))
             `(org-meta-line ((t :inherit fixed-pitch :foreground ,fg-shadow-subtle)))
             '(org-property-value ((t :inherit fixed-pitch)))
